package android.androidVNC;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.FilePermission;
import java.io.IOException;
import java.util.Calendar;
import java.util.GregorianCalendar;

import android.app.AlertDialog;
import android.graphics.Bitmap;
import android.graphics.drawable.Drawable;
import android.os.Environment;
import android.widget.Toast;

public class Screenshot {
	/**
	 * Realiza un screenshot de lo que vemos actualmente en pantalla
	 * @param vncCanvasActivity instancia de esta clase utilizada
	 * @param vncCanvas instancia de esta clase utilizada
	 * @return true si se realiza el screenshot correctamente, false en caso contrario
	 * @author Alberto Población Navarro
	 */
	static boolean nuevo(VncCanvasActivity vncCanvasActivity, VncCanvas vncCanvas){
		
		int num_imagen=0;
		boolean retorno = true;
		
	
		String sdcard_status = Environment.getExternalStorageState();
		File carpeta;
		//Comprobamos si hay un medio extraible donde se pueda guardar la imagen
        if(sdcard_status.equals(Environment.MEDIA_REMOVED)){
        	new AlertDialog.Builder(vncCanvasActivity)
	          .setTitle("No se encuentra Tarjeta SD")
	          .setMessage("No se puede guardar el screenshot en la sdCard")
	          .setIcon(android.R.drawable.ic_dialog_info)
	          .setPositiveButton(android.R.string.ok, null)
	          .show();
        	return false;
        	
        	
        }else carpeta = new File("/sdcard/screenshot");//Carpeta en la tarjeta donde se guardaran los pantallazos
		if(!carpeta.exists())
		  carpeta.mkdir(); //Si la carpeta no existe la creamos
		  
		 int dia=0;
		 int mes=0;
		 int year=0;
		 try{
			  dia = new GregorianCalendar().get(Calendar.DAY_OF_MONTH);
			  mes = new GregorianCalendar().get(Calendar.MONTH);
			  year = new GregorianCalendar().get(Calendar.YEAR);
		 }catch (Exception e) {
			if (e instanceof IllegalArgumentException){
				Toast.makeText(vncCanvasActivity, "La fecha no puede ser obtenida", Toast.LENGTH_SHORT).show();
				dia=mes=year=0;

			}
		 }
			 
		  
		  String nombre= new String("screenshot"+dia+mes+year+".jpeg");
		  //Archivo que usara el buffer de salida para guardar la imagen
		  File imagen = new File("/sdcard/screenshot/"+nombre); 
		  while(imagen.exists())
		  {
			  nombre= new String("screenshot"+dia+mes+year+"("+num_imagen+")"+".jpeg");
			  imagen= new File("/sdcard/screenshot/"+nombre);
			  num_imagen++;
		  }
		  num_imagen=0;
		  Bitmap nueva;
		  //Coje solo lo que vemos en la pantalla del movil
		  nueva = Bitmap.createBitmap(vncCanvas.bitmapData.mbitmap, 0, 0, vncCanvas.getWidth(), vncCanvas.getHeight());
		  //Para que coja toda la pantalla
		  //nueva = Bitmap.createBitmap(vncCanvas.bitmapData.mbitmap, 0, 0, vncCanvas.bitmapData.mbitmap.getWidth(), vncCanvas.bitmapData.mbitmap.getHeight());
		  
		  try{
			  FileOutputStream fos= new FileOutputStream(imagen);
			  nueva.compress(Bitmap.CompressFormat.JPEG,100,fos);
			  fos.flush();
			  fos.close();
			  Toast.makeText(vncCanvasActivity, "Screenshot:"+ nombre, Toast.LENGTH_SHORT).show();
			  
		  }catch (Exception e) {
			  //En caso de error mostramos cuadro de dialogo con el error
			  	  new AlertDialog.Builder(vncCanvasActivity)
		          .setTitle("Error")
		          .setMessage("Causa: "+e.toString())
		          .setIcon(android.R.drawable.ic_dialog_alert)
		          .setPositiveButton(android.R.string.ok, null)
		          .show();
				retorno=false;
			}finally{
				nueva.recycle();
			}
		  
		  
		  return retorno;
	}
}
